:py:mod:`piel.models.physical.thermal`
======================================

.. py:module:: piel.models.physical.thermal


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.physical.thermal.heat_transfer_1d_W



.. py:function:: heat_transfer_1d_W(thermal_conductivity_fit, temperature_range_K, cross_sectional_area_m2, length_m) -> float
